summaryrefslogtreecommitdiff
path: root/ports/rxv2/gnu/inc
diff options
context:
space:
mode:
authorYuxin Zhou <[email protected]>2021-03-05 05:38:33 +0000
committerYuxin Zhou <[email protected]>2021-03-05 05:38:33 +0000
commit10a7932b9d8a9f6f36523cb2f6edf13aa8dee6be (patch)
tree87461e5468fb0b4d1416e39fdbc51dceb5ffa2be /ports/rxv2/gnu/inc
parent32e3b3b25f4b17ff51ce8a6bad8d9eb32729a0f6 (diff)
Release 6.1.5v6.1.5_rel
Diffstat (limited to 'ports/rxv2/gnu/inc')
-rw-r--r--ports/rxv2/gnu/inc/tx_port.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/ports/rxv2/gnu/inc/tx_port.h b/ports/rxv2/gnu/inc/tx_port.h
index 57841625..912cf314 100644
--- a/ports/rxv2/gnu/inc/tx_port.h
+++ b/ports/rxv2/gnu/inc/tx_port.h
@@ -12,7 +12,7 @@
/**************************************************************************/
/**************************************************************************/
-/** */
+/** */
/** ThreadX Component */
/** */
/** Port Specific */
@@ -21,35 +21,35 @@
/**************************************************************************/
/**************************************************************************/
/* */
/* PORT SPECIFIC C INFORMATION RELEASE */
/* */
/* tx_port.h RX/GNURX */
/* 6.1.3 */
/* */
-/* AUTHOR */
-/* */
-/* William E. Lamie, Express Logic, Inc. */
-/* */
-/* DESCRIPTION */
-/* */
-/* This file contains data type definitions that make the ThreadX */
-/* real-time kernel function identically on a variety of different */
-/* processor architectures. For example, the size or number of bits */
-/* in an "int" data type vary between microprocessor architectures and */
-/* even C compilers for the same microprocessor. ThreadX does not */
-/* directly use native C data types. Instead, ThreadX creates its */
-/* own special types that can be mapped to actual data types by this */
-/* file to guarantee consistency in the interface and functionality. */
-/* */
-/* RELEASE HISTORY */
-/* */
-/* DATE NAME DESCRIPTION */
-/* */
+/* AUTHOR */
+/* */
+/* William E. Lamie, Express Logic, Inc. */
+/* */
+/* DESCRIPTION */
+/* */
+/* This file contains data type definitions that make the ThreadX */
+/* real-time kernel function identically on a variety of different */
+/* processor architectures. For example, the size or number of bits */
+/* in an "int" data type vary between microprocessor architectures and */
+/* even C compilers for the same microprocessor. ThreadX does not */
+/* directly use native C data types. Instead, ThreadX creates its */
+/* own special types that can be mapped to actual data types by this */
+/* file to guarantee consistency in the interface and functionality. */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
/* 12-31-2020 William E. Lamie Initial Version 6.1.3 */
-/* */
-/**************************************************************************/
+/* */
+/**************************************************************************/
#ifndef TX_PORT_H
#define TX_PORT_H
@@ -255,7 +255,7 @@ static void _tx_thread_system_return_inline(void)
#ifdef TX_THREAD_INIT
CHAR _tx_version_id[] =
- "Copyright (c) Microsoft Corporation. All rights reserved. * ThreadX RX/GNURX Version 6.1.3 *";
+ "Copyright (c) Microsoft Corporation. All rights reserved. * ThreadX RXv2/GNURX Version 6.1.3 *";
#else
extern CHAR _tx_version_id[];
#endif
@@ -21,35 +21,35 @@
/**************************************************************************/
-/**************************************************************************/
-/* */
-/* PORT SPECIFIC C INFORMATION RELEASE */
-/* */
-/* tx_port.h RX/GNURX */
+/**************************************************************************/
+/* */
+/* PORT SPECIFIC C INFORMATION RELEASE */
+/* */
+/* tx_port.h RXv2/GNURX */
/* 6.1.3 */
/* */